@@ -15,6 +15,8 @@
 #' @export
 xgx_geom_ci <- function(mapping = NULL, data = NULL, conf_level = 0.95,
                         distribution = "normal",
+                        bins = NULL,
+                        breaks = NULL,
                         geom = list("point", "line", "errorbar"),
                         position = "identity",
                         fun.args = list(),
@@ -22,13 +24,17 @@ xgx_geom_ci <- function(mapping = NULL, data = NULL, conf_level = 0.95,
                         show.legend = NA,
                         inherit.aes = TRUE,
                         ...) {
-  return(list(xgx_stat_ci(mapping, data, conf_level,
-                          distribution,
-                          geom,
-                          position,
-                          fun.args,
-                          na.rm,
-                          show.legend,
-                          inherit.aes,
+  return(list(xgx_stat_ci(mapping = mapping, 
+                          data = data, 
+                          conf_level = conf_level,
+                          distribution = distribution,
+                          bins = bins,
+                          breaks = breaks,
+                          geom = geom,
+                          position = position,
+                          fun.args = fun.args,
+                          na.rm = na.rm,
+                          show.legend = show.legend,
+                          inherit.aes = inherit.aes,
                           ...)))
 }
